
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef sick_POSTER_LIB_H
#define sick_POSTER_LIB_H

#include "posterLib.h"
#include "genom/genom.h"

/* Types definis ou utilises par le module */
#include "sickType.h"
#include "sickError.h"

/* 
 * Definition de la SDI_C 
*/
typedef struct {
  CNTRL_TASK_DESCRIPTION cntrlTask;
  EXEC_TASK_DESCRIPTION execTaskTab[SICK_NB_EXEC_TASK];
  ACTIVITY_DESCRIPTION activityTab[MAX_ACTIVITIES];
} SICK_CNTRL_STR;

/* For consistency with other posters */
typedef SICK_CNTRL_STR SICK_CNTRL_POSTER_STR;
 
/* 
 * Definition des structures de posters
 */
#include "sickPosterLibStruct.h"



/* Posters */
#define SICK_CNTRL_POSTER_NAME genomInstanceSuffixName("sick", "Cntrl")
#define SICK_SCANPOLAR_POSTER_NAME genomInstanceSuffixName("sick", "ScanPolar")
#define SICK_SCANCART_POSTER_NAME genomInstanceSuffixName("sick", "ScanCart")
#define SICK_CONFIG_POSTER_NAME genomInstanceSuffixName("sick", "Config")
#define SICK_SEGS_POSTER_NAME genomInstanceSuffixName("sick", "Segs")


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif
extern STATUS sickPosterInit ( void );
extern POSTER_ID sickCntrlPosterID ();
extern STATUS sickCntrlPosterRead ( SICK_CNTRL_STR *sickCntrlStrId );
extern STATUS sickCntrlPosterInit ( void );
extern STATUS sickCntrlInstancePosterRead(const char *name, SICK_CNTRL_STR *sickCntrlStrId);
extern STATUS sickScanPolarPosterInit ( void );
extern POSTER_ID sickScanPolarPosterID ( void );
extern STATUS sickScanPolarPosterRead ( SICK_SCANPOLAR_POSTER_STR *x );
extern STATUS sickScanPolarInstancePosterRead ( const char *, SICK_SCANPOLAR_POSTER_STR * );
extern STATUS sickScanPolarHeaderPosterRead ( SICK_MEASURES_HEADER_STR *Header );
extern STATUS sickScanPolarHeaderInstancePosterRead( const char *, SICK_MEASURES_HEADER_STR * );
extern STATUS sickScanPolarRhoPosterRead ( double *Rho );
extern STATUS sickScanPolarRhoInstancePosterRead( const char *, double * );
extern STATUS sickScanCartPosterInit ( void );
extern POSTER_ID sickScanCartPosterID ( void );
extern STATUS sickScanCartPosterRead ( SICK_SCANCART_POSTER_STR *x );
extern STATUS sickScanCartInstancePosterRead ( const char *, SICK_SCANCART_POSTER_STR * );
extern STATUS sickScanCartHeaderPosterRead ( SICK_MEASURES_HEADER_STR *Header );
extern STATUS sickScanCartHeaderInstancePosterRead( const char *, SICK_MEASURES_HEADER_STR * );
extern STATUS sickScanCartPointsPosterRead ( SICK_POINT *Points );
extern STATUS sickScanCartPointsInstancePosterRead( const char *, SICK_POINT * );
extern STATUS sickConfigPosterInit ( void );
extern POSTER_ID sickConfigPosterID ( void );
extern STATUS sickConfigPosterRead ( SICK_CONFIG_POSTER_STR *x );
extern STATUS sickConfigInstancePosterRead ( const char *, SICK_CONFIG_POSTER_STR * );
extern STATUS sickConfigStatePosterRead ( SICK_SCAN_TASK_STATE *State );
extern STATUS sickConfigStateInstancePosterRead( const char *, SICK_SCAN_TASK_STATE * );
extern STATUS sickConfigSickModePosterRead ( SICK_CONTROL_MODES *SickMode );
extern STATUS sickConfigSickModeInstancePosterRead( const char *, SICK_CONTROL_MODES * );
extern STATUS sickConfigConfigPosterRead ( SICK_CONFIG_STR *Config );
extern STATUS sickConfigConfigInstancePosterRead( const char *, SICK_CONFIG_STR * );
extern STATUS sickSegsPosterInit ( void );
extern POSTER_ID sickSegsPosterID ( void );
extern STATUS sickSegsPosterRead ( SICK_SEGS_POSTER_STR *x );
extern STATUS sickSegsInstancePosterRead ( const char *, SICK_SEGS_POSTER_STR * );
extern STATUS sickSegsHeaderPosterRead ( SICK_SEG_HEADER *Header );
extern STATUS sickSegsHeaderInstancePosterRead( const char *, SICK_SEG_HEADER * );
extern STATUS sickSegsSegsPosterRead ( SICK_SEGS *Segs );
extern STATUS sickSegsSegsInstancePosterRead( const char *, SICK_SEGS * );
extern STATUS sickSegsPointsPosterRead ( SICK_LONELY_PTS *Points );
extern STATUS sickSegsPointsInstancePosterRead( const char *, SICK_LONELY_PTS * );
#ifdef __cplusplus
}
#endif
#endif

